@@ -3,7 +3,9 @@ from functools import wraps
 import inspect
 from collections import defaultdict
 from django.core.exceptions import PermissionDenied
-from .templatetags.perms import register as template_register
+from django.contrib.auth.decorators import login_required
+from django.shortcuts import get_object_or_404
+from .templatetags.permissions import register as template_register
 
 __all__ = ['permission']
 
@@ -101,6 +103,10 @@ def decorate(view_function, perm_function):
         user = request.user
         perm_name = perm_function.__name__
 
+        # anons have no permissions
+        if user.is_anonymous():
+            return login_required(lambda *args, **kwargs: 1)(request)
+
         # are we dealing with a perm function that has an associated model class?
         model = perm_attributes[perm_name].get("model", None)
         if model is not None:
@@ -111,7 +117,7 @@ def decorate(view_function, perm_function):
                 params = view_function.func_code.co_varnames
                 model_pk = kwargs[params[1]]
 
-            model_obj = model.objects.get(pk=model_pk)
+            model_obj = get_object_or_404(model, pk=model_pk)
             test = perm_function(user, model_obj)
         else:
             test = perm_function(user)
